==> haskell-turtle-1.4.3-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-turtle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: turtle
version: 1.4.3
id: turtle-1.4.3-8qzplIEch7hJEUjLXOmMja
key: turtle-1.4.3-8qzplIEch7hJEUjLXOmMja
license: BSD3
copyright: 2015 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Shell programming, Haskell-style
description:
    @turtle@ is a reimplementation of the Unix command line environment
    in Haskell so that you can use Haskell as both a shell and a scripting
    language.
    .
    Features include:
    .
    * Batteries included: Command an extended suite of predefined utilities
    .
    * Interoperability: You can still run external shell commands
    .
    * Portability: Works on Windows, OS X, and Linux
    .
    * Exception safety: Safely acquire and release resources
    .
    * Streaming: Transform or fold command output in constant space
    .
    * Patterns: Use typed regular expressions that can parse structured values
    .
    * Formatting: Type-safe @printf@-style text formatting
    .
    * Modern: Supports @text@ and @system-filepath@
    .
    Read "Turtle.Tutorial" for a detailed tutorial or "Turtle.Prelude" for a
    quick-start guide
    .
    @turtle@ is designed to be beginner-friendly, but as a result lacks certain
    features, like tracing commands.  If you feel comfortable using @turtle@
    then you should also check out the @Shelly@ library which provides similar
    functionality.
category: System
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Turtle Turtle.Bytes Turtle.Format Turtle.Line Turtle.Options
    Turtle.Pattern Turtle.Prelude Turtle.Shell Turtle.Tutorial
hidden-modules: Turtle.Internal
abi: 93ca630ae452528825edcf7158cd25db
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/turtle-1.4.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/turtle-1.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/turtle-1.4.3
hs-libraries: HSturtle-1.4.3-8qzplIEch7hJEUjLXOmMja
depends:
    base-4.10.0.0 ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk
    async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc bytestring-0.10.8.2
    clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg directory-1.3.0.2
    foldl-1.3.0-LlHPkE5iGmH66qtSdqJLo5
    hostname-1.0-ITdZPWe9XL7105h6B80pVP
    managed-1.0.5-AtVs0QEjn5cnY7UxRWyLE process-1.6.1.0
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    system-filepath-0.4.13.4-H5ZT610b48ZDAWGB9PlvnB
    system-fileio-0.3.16.3-8q55Bl57w6jJvYSIouKL6q
    stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ
    temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    transformers-0.5.2.0
    optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2
    optional-args-1.0.1-Ca5saO7bmrq5UodVMXfAMM
    unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp unix-2.7.2.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk=dd8d552288e499e2e21b7896e82609e8
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=12ffabdf3957a0bddb91126c0d755daa
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg=1e1baf841d0fcad1b9eca88e567ce03e
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             foldl-1.3.0-LlHPkE5iGmH66qtSdqJLo5=6d5eddf6b320081945a6398d3d0f5c29
             hostname-1.0-ITdZPWe9XL7105h6B80pVP=729452e5897009ef3942b1becb0fb5f7
             managed-1.0.5-AtVs0QEjn5cnY7UxRWyLE=71d1fe5f44b53269736a045fba484b18
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             system-filepath-0.4.13.4-H5ZT610b48ZDAWGB9PlvnB=fe5a792986a644165f83a6cf5aa32906
             system-fileio-0.3.16.3-8q55Bl57w6jJvYSIouKL6q=bfb9ed67d9f06ace05e54b4f67e700eb
             stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ=a88f5bbac4be96a38c5ca2a658c158a0
             temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo=b2bbe16ff4ee22883b159097e4afbbd0
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2=8c6e4212da58d8bc69ad7a6f814edde6
             optional-args-1.0.1-Ca5saO7bmrq5UodVMXfAMM=430ecd8445550e022a4abd31c484de06
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=de9563896484115ad3fe305bce9cecd3
             unix-2.7.2.2=53184c24da5ad45126d145b2febba63d
haddock-interfaces: /usr/share/doc/haskell-turtle/html/turtle.haddock
haddock-html: /usr/share/doc/haskell-turtle/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-turtle-1.4.3-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-turtle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: turtle
version: 1.4.3
id: turtle-1.4.3-J9wc3EAkvzFJPopu48JGsJ
key: turtle-1.4.3-J9wc3EAkvzFJPopu48JGsJ
license: BSD3
copyright: 2015 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
synopsis: Shell programming, Haskell-style
description:
    @turtle@ is a reimplementation of the Unix command line environment
    in Haskell so that you can use Haskell as both a shell and a scripting
    language.
    .
    Features include:
    .
    * Batteries included: Command an extended suite of predefined utilities
    .
    * Interoperability: You can still run external shell commands
    .
    * Portability: Works on Windows, OS X, and Linux
    .
    * Exception safety: Safely acquire and release resources
    .
    * Streaming: Transform or fold command output in constant space
    .
    * Patterns: Use typed regular expressions that can parse structured values
    .
    * Formatting: Type-safe @printf@-style text formatting
    .
    * Modern: Supports @text@ and @system-filepath@
    .
    Read "Turtle.Tutorial" for a detailed tutorial or "Turtle.Prelude" for a
    quick-start guide
    .
    @turtle@ is designed to be beginner-friendly, but as a result lacks certain
    features, like tracing commands.  If you feel comfortable using @turtle@
    then you should also check out the @Shelly@ library which provides similar
    functionality.
category: System
author: Gabriel Gonzalez
exposed: True
indefinite: False
exposed-modules:
    Turtle Turtle.Bytes Turtle.Format Turtle.Line Turtle.Options
    Turtle.Pattern Turtle.Prelude Turtle.Shell Turtle.Tutorial
hidden-modules: Turtle.Internal
abi: c5d16e4104c24d0249dcee6693826cbe
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/turtle-1.4.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/turtle-1.4.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/turtle-1.4.3
hs-libraries: HSturtle-1.4.3-J9wc3EAkvzFJPopu48JGsJ
depends:
    base-4.10.0.0 ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk
    async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc bytestring-0.10.8.2
    clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg directory-1.3.0.2
    foldl-1.3.1-CMCmGio2p0gKJ3J33ms7lU
    hostname-1.0-ITdZPWe9XL7105h6B80pVP
    managed-1.0.5-AtVs0QEjn5cnY7UxRWyLE process-1.6.1.0
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    system-filepath-0.4.13.4-H5ZT610b48ZDAWGB9PlvnB
    system-fileio-0.3.16.3-8q55Bl57w6jJvYSIouKL6q
    stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ
    temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    transformers-0.5.2.0
    optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2
    optional-args-1.0.1-Ca5saO7bmrq5UodVMXfAMM
    unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp unix-2.7.2.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             ansi-wl-pprint-0.6.8.1-80vSxm39oopFZHdKk9kEEk=dd8d552288e499e2e21b7896e82609e8
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=12ffabdf3957a0bddb91126c0d755daa
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             clock-0.7.2-9fV7rV7wNUo6v6mDurfiVg=1e1baf841d0fcad1b9eca88e567ce03e
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             foldl-1.3.1-CMCmGio2p0gKJ3J33ms7lU=3dad66fc36c00507a14f542a1d7a549c
             hostname-1.0-ITdZPWe9XL7105h6B80pVP=729452e5897009ef3942b1becb0fb5f7
             managed-1.0.5-AtVs0QEjn5cnY7UxRWyLE=71d1fe5f44b53269736a045fba484b18
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             system-filepath-0.4.13.4-H5ZT610b48ZDAWGB9PlvnB=fe5a792986a644165f83a6cf5aa32906
             system-fileio-0.3.16.3-8q55Bl57w6jJvYSIouKL6q=bfb9ed67d9f06ace05e54b4f67e700eb
             stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ=a88f5bbac4be96a38c5ca2a658c158a0
             temporary-1.2.1.1-JiAl6vZksoXBKGEB3ysIBo=b2bbe16ff4ee22883b159097e4afbbd0
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2=8c6e4212da58d8bc69ad7a6f814edde6
             optional-args-1.0.1-Ca5saO7bmrq5UodVMXfAMM=430ecd8445550e022a4abd31c484de06
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=de9563896484115ad3fe305bce9cecd3
             unix-2.7.2.2=53184c24da5ad45126d145b2febba63d
haddock-interfaces: /usr/share/doc/haskell-turtle/html/turtle.haddock
haddock-html: /usr/share/doc/haskell-turtle/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
